:mod:`art.classifiers`
======================
.. automodule:: art.classifiers

Base Class
----------
.. autoclass:: Classifier
   :members:

Framework-Specific Model Wrappers
---------------------------------
.. autoclass:: KerasClassifier
   :members:
.. autoclass:: MXClassifier
   :members:
.. autoclass:: PyTorchClassifier
   :members:
.. autoclass:: TFClassifier
   :members:

Ensemble Wrapper
----------------
.. autoclass:: EnsembleClassifier
   :members:
